# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageSourcesPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkGenerateImageSourcePython
else:
    import _itkGenerateImageSourcePython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkImagePython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkIndexPython
import itk.itkRGBPixelPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
class itkGenerateImageSourceICF2(itk.itkImageSourcePython.itkImageSourceICF2):
    r"""Proxy of C++ itkGenerateImageSourceICF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceICF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceICF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF2_cast(obj)

# Register itkGenerateImageSourceICF2 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceICF2_swigregister(itkGenerateImageSourceICF2)
class itkGenerateImageSourceICF3(itk.itkImageSourcePython.itkImageSourceICF3):
    r"""Proxy of C++ itkGenerateImageSourceICF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceICF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceICF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICF3_cast(obj)

# Register itkGenerateImageSourceICF3 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceICF3_swigregister(itkGenerateImageSourceICF3)
class itkGenerateImageSourceICVF22(itk.itkImageSourcePython.itkImageSourceICVF22):
    r"""Proxy of C++ itkGenerateImageSourceICVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceICVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceICVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_cast(obj)

# Register itkGenerateImageSourceICVF22 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceICVF22_swigregister(itkGenerateImageSourceICVF22)
class itkGenerateImageSourceICVF23(itk.itkImageSourcePython.itkImageSourceICVF23):
    r"""Proxy of C++ itkGenerateImageSourceICVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceICVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceICVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_cast(obj)

# Register itkGenerateImageSourceICVF23 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceICVF23_swigregister(itkGenerateImageSourceICVF23)
class itkGenerateImageSourceICVF32(itk.itkImageSourcePython.itkImageSourceICVF32):
    r"""Proxy of C++ itkGenerateImageSourceICVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceICVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceICVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_cast(obj)

# Register itkGenerateImageSourceICVF32 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceICVF32_swigregister(itkGenerateImageSourceICVF32)
class itkGenerateImageSourceICVF33(itk.itkImageSourcePython.itkImageSourceICVF33):
    r"""Proxy of C++ itkGenerateImageSourceICVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceICVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceICVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_cast(obj)

# Register itkGenerateImageSourceICVF33 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceICVF33_swigregister(itkGenerateImageSourceICVF33)
class itkGenerateImageSourceICVF42(itk.itkImageSourcePython.itkImageSourceICVF42):
    r"""Proxy of C++ itkGenerateImageSourceICVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceICVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceICVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_cast(obj)

# Register itkGenerateImageSourceICVF42 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceICVF42_swigregister(itkGenerateImageSourceICVF42)
class itkGenerateImageSourceICVF43(itk.itkImageSourcePython.itkImageSourceICVF43):
    r"""Proxy of C++ itkGenerateImageSourceICVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceICVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceICVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_cast(obj)

# Register itkGenerateImageSourceICVF43 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceICVF43_swigregister(itkGenerateImageSourceICVF43)
class itkGenerateImageSourceIF2(itk.itkImageSourcePython.itkImageSourceIF2):
    r"""Proxy of C++ itkGenerateImageSourceIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF2_cast(obj)

# Register itkGenerateImageSourceIF2 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIF2_swigregister(itkGenerateImageSourceIF2)
class itkGenerateImageSourceIF3(itk.itkImageSourcePython.itkImageSourceIF3):
    r"""Proxy of C++ itkGenerateImageSourceIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIF3_cast(obj)

# Register itkGenerateImageSourceIF3 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIF3_swigregister(itkGenerateImageSourceIF3)
class itkGenerateImageSourceIRGBAUC2(itk.itkImageSourcePython.itkImageSourceIRGBAUC2):
    r"""Proxy of C++ itkGenerateImageSourceIRGBAUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIRGBAUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIRGBAUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_cast(obj)

# Register itkGenerateImageSourceIRGBAUC2 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC2_swigregister(itkGenerateImageSourceIRGBAUC2)
class itkGenerateImageSourceIRGBAUC3(itk.itkImageSourcePython.itkImageSourceIRGBAUC3):
    r"""Proxy of C++ itkGenerateImageSourceIRGBAUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIRGBAUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIRGBAUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_cast(obj)

# Register itkGenerateImageSourceIRGBAUC3 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIRGBAUC3_swigregister(itkGenerateImageSourceIRGBAUC3)
class itkGenerateImageSourceIRGBUC2(itk.itkImageSourcePython.itkImageSourceIRGBUC2):
    r"""Proxy of C++ itkGenerateImageSourceIRGBUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIRGBUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIRGBUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_cast(obj)

# Register itkGenerateImageSourceIRGBUC2 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC2_swigregister(itkGenerateImageSourceIRGBUC2)
class itkGenerateImageSourceIRGBUC3(itk.itkImageSourcePython.itkImageSourceIRGBUC3):
    r"""Proxy of C++ itkGenerateImageSourceIRGBUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIRGBUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIRGBUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_cast(obj)

# Register itkGenerateImageSourceIRGBUC3 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIRGBUC3_swigregister(itkGenerateImageSourceIRGBUC3)
class itkGenerateImageSourceISS2(itk.itkImageSourcePython.itkImageSourceISS2):
    r"""Proxy of C++ itkGenerateImageSourceISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS2_cast(obj)

# Register itkGenerateImageSourceISS2 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceISS2_swigregister(itkGenerateImageSourceISS2)
class itkGenerateImageSourceISS3(itk.itkImageSourcePython.itkImageSourceISS3):
    r"""Proxy of C++ itkGenerateImageSourceISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISS3_cast(obj)

# Register itkGenerateImageSourceISS3 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceISS3_swigregister(itkGenerateImageSourceISS3)
class itkGenerateImageSourceISSRTD22(itk.itkImageSourcePython.itkImageSourceISSRTD22):
    r"""Proxy of C++ itkGenerateImageSourceISSRTD22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceISSRTD22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceISSRTD22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_cast(obj)

# Register itkGenerateImageSourceISSRTD22 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD22_swigregister(itkGenerateImageSourceISSRTD22)
class itkGenerateImageSourceISSRTD33(itk.itkImageSourcePython.itkImageSourceISSRTD33):
    r"""Proxy of C++ itkGenerateImageSourceISSRTD33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceISSRTD33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceISSRTD33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_cast(obj)

# Register itkGenerateImageSourceISSRTD33 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceISSRTD33_swigregister(itkGenerateImageSourceISSRTD33)
class itkGenerateImageSourceISSRTF22(itk.itkImageSourcePython.itkImageSourceISSRTF22):
    r"""Proxy of C++ itkGenerateImageSourceISSRTF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceISSRTF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceISSRTF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_cast(obj)

# Register itkGenerateImageSourceISSRTF22 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF22_swigregister(itkGenerateImageSourceISSRTF22)
class itkGenerateImageSourceISSRTF33(itk.itkImageSourcePython.itkImageSourceISSRTF33):
    r"""Proxy of C++ itkGenerateImageSourceISSRTF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceISSRTF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceISSRTF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_cast(obj)

# Register itkGenerateImageSourceISSRTF33 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceISSRTF33_swigregister(itkGenerateImageSourceISSRTF33)
class itkGenerateImageSourceIUC2(itk.itkImageSourcePython.itkImageSourceIUC2):
    r"""Proxy of C++ itkGenerateImageSourceIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_cast(obj)

# Register itkGenerateImageSourceIUC2 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIUC2_swigregister(itkGenerateImageSourceIUC2)
class itkGenerateImageSourceIUC3(itk.itkImageSourcePython.itkImageSourceIUC3):
    r"""Proxy of C++ itkGenerateImageSourceIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_cast(obj)

# Register itkGenerateImageSourceIUC3 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIUC3_swigregister(itkGenerateImageSourceIUC3)
class itkGenerateImageSourceIVF22(itk.itkImageSourcePython.itkImageSourceIVF22):
    r"""Proxy of C++ itkGenerateImageSourceIVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_cast(obj)

# Register itkGenerateImageSourceIVF22 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIVF22_swigregister(itkGenerateImageSourceIVF22)
class itkGenerateImageSourceIVF23(itk.itkImageSourcePython.itkImageSourceIVF23):
    r"""Proxy of C++ itkGenerateImageSourceIVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_cast(obj)

# Register itkGenerateImageSourceIVF23 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIVF23_swigregister(itkGenerateImageSourceIVF23)
class itkGenerateImageSourceIVF32(itk.itkImageSourcePython.itkImageSourceIVF32):
    r"""Proxy of C++ itkGenerateImageSourceIVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_cast(obj)

# Register itkGenerateImageSourceIVF32 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIVF32_swigregister(itkGenerateImageSourceIVF32)
class itkGenerateImageSourceIVF33(itk.itkImageSourcePython.itkImageSourceIVF33):
    r"""Proxy of C++ itkGenerateImageSourceIVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_cast(obj)

# Register itkGenerateImageSourceIVF33 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIVF33_swigregister(itkGenerateImageSourceIVF33)
class itkGenerateImageSourceIVF42(itk.itkImageSourcePython.itkImageSourceIVF42):
    r"""Proxy of C++ itkGenerateImageSourceIVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_cast(obj)

# Register itkGenerateImageSourceIVF42 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIVF42_swigregister(itkGenerateImageSourceIVF42)
class itkGenerateImageSourceIVF43(itk.itkImageSourcePython.itkImageSourceIVF43):
    r"""Proxy of C++ itkGenerateImageSourceIVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceIVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceIVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_cast(obj)

# Register itkGenerateImageSourceIVF43 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceIVF43_swigregister(itkGenerateImageSourceIVF43)
class itkGenerateImageSourceVIF2(itk.itkImageSourcePython.itkImageSourceVIF2):
    r"""Proxy of C++ itkGenerateImageSourceVIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceVIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceVIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_cast(obj)

# Register itkGenerateImageSourceVIF2 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceVIF2_swigregister(itkGenerateImageSourceVIF2)
class itkGenerateImageSourceVIF3(itk.itkImageSourcePython.itkImageSourceVIF3):
    r"""Proxy of C++ itkGenerateImageSourceVIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceVIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceVIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_cast(obj)

# Register itkGenerateImageSourceVIF3 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceVIF3_swigregister(itkGenerateImageSourceVIF3)
class itkGenerateImageSourceVISS2(itk.itkImageSourcePython.itkImageSourceVISS2):
    r"""Proxy of C++ itkGenerateImageSourceVISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceVISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceVISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_cast(obj)

# Register itkGenerateImageSourceVISS2 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceVISS2_swigregister(itkGenerateImageSourceVISS2)
class itkGenerateImageSourceVISS3(itk.itkImageSourcePython.itkImageSourceVISS3):
    r"""Proxy of C++ itkGenerateImageSourceVISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceVISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceVISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_cast(obj)

# Register itkGenerateImageSourceVISS3 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceVISS3_swigregister(itkGenerateImageSourceVISS3)
class itkGenerateImageSourceVIUC2(itk.itkImageSourcePython.itkImageSourceVIUC2):
    r"""Proxy of C++ itkGenerateImageSourceVIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD22"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase2 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceVIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceVIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_cast(obj)

# Register itkGenerateImageSourceVIUC2 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceVIUC2_swigregister(itkGenerateImageSourceVIUC2)
class itkGenerateImageSourceVIUC3(itk.itkImageSourcePython.itkImageSourceVIUC3):
    r"""Proxy of C++ itkGenerateImageSourceVIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_GetUseReferenceImage(self)

    def GetSize(self):
        r"""GetSize(self) -> itkSize3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_GetSize(self)

    def SetSize(self, *args):
        r"""
        SetSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        SetSize(self, data)

        Parameters
        ----------
        data: unsigned long *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_SetSize(self, *args)

    def GetSpacing(self):
        r"""GetSpacing(self) -> itkVectorD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_GetSpacing(self)

    def SetSpacing(self, *args):
        r"""
        SetSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetSpacing(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_SetSpacing(self, *args)

    def GetOrigin(self):
        r"""GetOrigin(self) -> itkPointD3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_GetOrigin(self)

    def SetOrigin(self, *args):
        r"""
        SetOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOrigin(self, data)

        Parameters
        ----------
        data: float const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_SetOrigin(self, *args)

    def SetDirection(self, _arg):
        r"""
        SetDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_SetDirection(self, _arg)

    def GetDirection(self):
        r"""GetDirection(self) -> itkMatrixD33"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_GetDirection(self)

    def SetStartIndex(self, _arg):
        r"""
        SetStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_SetStartIndex(self, _arg)

    def GetStartIndex(self):
        r"""GetStartIndex(self) -> itkIndex3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_GetStartIndex(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_SetOutputParametersFromImage(self, image)

    def SetReferenceImage(self, _arg):
        r"""
        SetReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageBase3 const *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_SetReferenceImage(self, _arg)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_GetReferenceImage(self)
    __swig_destroy__ = _itkGenerateImageSourcePython.delete_itkGenerateImageSourceVIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGenerateImageSourceVIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_cast(obj)

# Register itkGenerateImageSourceVIUC3 in _itkGenerateImageSourcePython:
_itkGenerateImageSourcePython.itkGenerateImageSourceVIUC3_swigregister(itkGenerateImageSourceVIUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def generate_image_source(*args,  use_reference_image: bool=..., size: Sequence[int]=..., spacing: Sequence[float]=..., origin: Sequence[float]=..., direction=..., start_index: Sequence[int]=..., output_parameters_from_image: itkt.ImageBase=..., reference_image: itkt.ImageBase=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for GenerateImageSource"""
    import itk

    kwarg_typehints = { 'use_reference_image':use_reference_image,'size':size,'spacing':spacing,'origin':origin,'direction':direction,'start_index':start_index,'output_parameters_from_image':output_parameters_from_image,'reference_image':reference_image }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.GenerateImageSource.New(*args, **kwargs)

    return instance.__internal_call__()

def generate_image_source_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageSources.GenerateImageSource
    generate_image_source.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    generate_image_source.__doc__ = filter_object.__doc__



